@@ -442,7 +442,9 @@ const Application = new Lang.Class({
                 'Carlos Garnacho <carlosg@gnome.org>',
                 'Jonas Danielsson <jonas.danielsson@threetimestwo.org>',
                 'Bastian Ilsø <bastianilso@gnome.org>',
-                'Kunaal Jain <kunaalus@gmail.com>'
+                'Kunaal Jain <kunaalus@gmail.com>',
+                'Cody Welsh <codyw@protonmail.com>',
+                'Isabella Ribeiro <belinhacbr@gmail.com>'
             ],
             artists: [
                 'Sam Hewitt',
@@ -454,6 +456,7 @@ const Application = new Lang.Class({
             license_type: Gtk.License.GPL_2_0,
             logo_icon_name: 'polari',
             version: pkg.version,
+            website_label: _("Learn more about Polari"),
             website: 'https://wiki.gnome.org/Apps/Polari',
 
             transient_for: this._window.window,
